@@ -3,6 +3,7 @@
 Functions related to handling and checking targets
 """
 
+from urllib.parse import urlparse
 from .base import Plugin
 
 
@@ -40,6 +41,35 @@ class Targets(Plugin):
             slug = targets[0].slug
         return slug
 
+    def build_scope_web_burp(self, scope):
+        """Return a Burp Suite scope given retrieved web scope"""
+        ret = {'target': {'scope': {'advanced_mode': 'true', 'exclude': [], 'include': []}}}
+        for asset in scope:
+            state = 'include' if asset['status'] == 'in' else 'exclude'
+            raw = urlparse(asset['raw_url'])
+            for item in asset['rules']:
+                item = item['rule'].strip('.*')
+                url = urlparse(item)
+                if len(url.netloc) == 0:
+                    url = urlparse(raw.scheme + '://' + item)
+                ret['target']['scope'][state].append({
+                    'enabled': True if url.hostname else False,
+                    'scheme': url.scheme if url.scheme else 'any',
+                    'host': url.hostname,
+                    'file': url.path
+                })
+        return ret
+
+    def build_scope_web_urls(self, scope):
+        """Return a list of the raw urls gived a retrieved web scope"""
+        ret = {"in": list(), "out": list()}
+        for asset in scope:
+            if asset["status"] == "in":
+                ret["in"].append(asset["raw_url"])
+            else:
+                ret["out"].append(asset["raw_url"])
+        return ret
+
     def get_assessments(self):
         """Check which assessments have been completed"""
         res = self.api.request('GET', 'assessments')
@@ -52,8 +82,7 @@ class Targets(Plugin):
         target = self.db.find_targets(**kwargs)[0]
         if target:
             res = self.api.request('POST',
-                                   'asset/v1/organizations/' +
-                                   target.organization +
+                                   f'asset/v1/organizations/{target.organization}' +
                                    f'/owners/listings/{target.slug}' +
                                    f'/users/{self.db.user_id}' +
                                    '/credentials')
@@ -89,6 +118,45 @@ class Targets(Plugin):
                 ret[t['id']] = t
         return ret
 
+    def get_scope(self, **kwargs):
+        """Get the scope of a target"""
+        target = self.db.find_targets(**kwargs)
+        if target:
+            target = target[0]
+            categories = dict()
+            for category in self.db.categories:
+                categories[category.id] = category.name
+            if categories[target.category].lower() == 'host':
+                return self.get_scope_host(target)
+            elif categories[target.category].lower() == 'web application':
+                return self.get_scope_web(target)
+
+    def get_scope_host(self, target=None, **kwargs):
+        """Get the scope of a Host target"""
+        if target is None:
+            target = self.db.find_targets(**kwargs)
+            if target:
+                target = target[0]
+        if target:
+            res = self.api.request('GET', f'targets/{target.slug}/cidrs?page=all')
+            if res.status_code == 200:
+                return res.json()['cidrs']
+
+    def get_scope_web(self, target=None, **kwargs):
+        """Get the scope of a Web target"""
+        if target is None:
+            target = self.db.find_targets(**kwargs)
+            if target:
+                target = target[0]
+        res = self.api.request('GET', f'asset/v1/organizations/{target.organization}' +
+                                      f'/owners/listings/{target.slug}/webapps')
+        if res.status_code == 200:
+            scope = list()
+            for asset in res.json():
+                if target.slug in [o['owner_uid'] for o in asset['owners']]:
+                    scope.append(asset)
+            return scope
+
     def get_unregistered(self):
         """Get slugs of all unregistered targets"""
         if not self.db.categories:
